==> symfony_5.2.6+dfsg.orig.tar.xz: symfony-5.2.6/src/Symfony/Bundle/FrameworkBundle/Tests/DependencyInjection/Fixtures/php/cache.php <==
<?php

$container->loadFromExtension('framework', [
    'cache' => [
        'pools' => [
            'cache.foo' => [
                'adapter' => 'cache.adapter.apcu',
                'default_lifetime' => 30,
            ],
            'cache.bar' => [
                'adapter' => 'cache.adapter.doctrine',
                'default_lifetime' => 5,
                'provider' => 'app.doctrine_cache_provider',
            ],
            'cache.baz' => [
                'adapter' => 'cache.adapter.filesystem',
                'default_lifetime' => 7,
            ],
            'cache.foobar' => [
                'adapter' => 'cache.adapter.psr6',
                'default_lifetime' => 10,
                'provider' => 'app.cache_pool',
            ],
            'cache.def' => [
                'default_lifetime' => 'PT11S',
            ],
            'cache.expr' => [
                'default_lifetime' => '13 seconds',
            ],
            'cache.chain' => [
                'default_lifetime' => 12,
                'adapter' => [
                    'cache.adapter.array',
                    'cache.adapter.filesystem',
                    'redis://foo' => 'cache.adapter.redis',
                ],
            ],
            'cache.redis_tag_aware.foo' => [
                'adapter' => 'cache.adapter.redis_tag_aware',
            ],
            'cache.redis_tag_aware.foo2' => [
                'tags' => true,
                'adapter' => 'cache.adapter.redis_tag_aware',
            ],
            'cache.redis_tag_aware.bar' => [
                'adapter' => 'cache.redis_tag_aware.foo',
            ],
            'cache.redis_tag_aware.bar2' => [
                'tags' => true,
                'adapter' => 'cache.redis_tag_aware.foo',
            ],
            'cache.redis_tag_aware.baz' => [
                'adapter' => 'cache.redis_tag_aware.foo2',
            ],
            'cache.redis_tag_aware.baz2' => [
                'tags' => true,
                'adapter' => 'cache.redis_tag_aware.foo2',
            ],
        ],
    ],
]);

==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Bundle/FrameworkBundle/Tests/DependencyInjection/Fixtures/php/cache.php <==
<?php

$container->loadFromExtension('framework', [
    'cache' => [
        'pools' => [
            'cache.foo' => [
                'adapter' => 'cache.adapter.apcu',
                'default_lifetime' => 30,
            ],
            'cache.baz' => [
                'adapter' => 'cache.adapter.filesystem',
                'default_lifetime' => 7,
            ],
            'cache.foobar' => [
                'adapter' => 'cache.adapter.psr6',
                'default_lifetime' => 10,
                'provider' => 'app.cache_pool',
            ],
            'cache.def' => [
                'default_lifetime' => 'PT11S',
            ],
            'cache.expr' => [
                'default_lifetime' => '13 seconds',
            ],
            'cache.chain' => [
                'default_lifetime' => 12,
                'adapter' => [
                    'cache.adapter.array',
                    'cache.adapter.filesystem',
                    'redis://foo' => 'cache.adapter.redis',
                ],
            ],
            'cache.ccc' => [
                'adapter' => 'cache.adapter.array',
                'default_lifetime' => 410,
                'tags' => true,
            ],
            'cache.redis_tag_aware.foo' => [
                'adapter' => 'cache.adapter.redis_tag_aware',
            ],
            'cache.redis_tag_aware.foo2' => [
                'tags' => true,
                'adapter' => 'cache.adapter.redis_tag_aware',
            ],
            'cache.redis_tag_aware.bar' => [
                'adapter' => 'cache.redis_tag_aware.foo',
            ],
            'cache.redis_tag_aware.bar2' => [
                'tags' => true,
                'adapter' => 'cache.redis_tag_aware.foo',
            ],
            'cache.redis_tag_aware.baz' => [
                'adapter' => 'cache.redis_tag_aware.foo2',
            ],
            'cache.redis_tag_aware.baz2' => [
                'tags' => true,
                'adapter' => 'cache.redis_tag_aware.foo2',
            ],
        ],
    ],
]);
